# <img src="img/omnifold_logo.png" width="100"> OmniFold

A method for universally unfolding collider data with machine learning-based reweighting.


Emily Dickinson, \#975  
>The Mountain sat upon the Plain  
>In his tremendous Chair&mdash;  
>His observation omnifold,  
>His inquest, everywhere&mdash;  
>  
>The Seasons played around his knees  
>Like Children round a sire&mdash;  
>Grandfather of the Days is He  
>Of Dawn, the Ancestor&mdash;  
